@@ -302,9 +302,11 @@ static int sql_fetch_row(void *s, void *resource, void **row)
 static int sql_fetch_field(void *session, void *resource, void *r,
                            unsigned int column_num, const char **value, size_t *len)
 {
+        int nfields;
         struct pg_result *res = resource;
 
-        if ( column_num >= PQnfields(res->result) )
+        nfields = PQnfields(res->result);
+        if ( nfields < 0 || column_num >= (unsigned int) nfields )
                 return preludedb_error(PRELUDEDB_ERROR_INVALID_COLUMN_NUM);
 
         if ( PQgetisnull(res->result, res->row, column_num) )
@@ -391,7 +393,7 @@ static int sql_build_time_constraint_string(prelude_string_t *output, const char
         int ret;
 
         ret = snprintf(buf, sizeof (buf), "%s + INTERVAL '%d HOUR'", field, gmt_offset / 3600);
-        if ( ret < 0 || ret >= sizeof (buf) )
+        if ( ret < 0 || (size_t) ret >= sizeof (buf) )
                 return preludedb_error(PRELUDEDB_ERROR_GENERIC);
 
         sql_operator = get_operator_string(operator);
@@ -476,7 +478,7 @@ static int sql_build_time_interval_string(preludedb_sql_time_constraint_type_t t
 
         ret = snprintf(buf, size, "INTERVAL '%d %s'", value, type_str);
 
-        return (ret < 0 || ret >= size) ? preludedb_error(PRELUDEDB_ERROR_GENERIC) : 0;
+        return (ret < 0 || (size_t) ret >= size) ? preludedb_error(PRELUDEDB_ERROR_GENERIC) : 0;
 }
 
 
