@@ -202,12 +202,16 @@ static void flush_transaction_if_needed(preludedb_t *db, unsigned int *event_no,
         if ( ! event_no )
                 cur_count += increment;
 
-        else if ( events_per_transaction && ((*event_no) += increment) >= events_per_transaction ) {
-                preludedb_transaction_end(db);
-                preludedb_transaction_start(db);
+        else if ( events_per_transaction ) {
+                (*event_no) += increment;
 
-                cur_count += *event_no;
-                *event_no = 0;
+                if ( *event_no >= events_per_transaction || (increment == 0 && *event_no) ) {
+                        preludedb_transaction_end(db);
+                        preludedb_transaction_start(db);
+
+                        cur_count += *event_no;
+                        *event_no = 0;
+                }
         }
 }
 
@@ -276,14 +280,14 @@ static int db_error(preludedb_t *db, ssize_t ret, const char *fmt, ...)
 
 
 
-static int fetch_message_idents_limited(preludedb_t *db, preludedb_result_idents_t **result)
+static int fetch_message_idents_limited(preludedb_t *db, preludedb_result_idents_t **result, prelude_bool_t no_increment)
 {
         int count;
         int64_t local_limit;
 
         local_limit = (limit_copy < 0) ? events_per_transaction : MIN(events_per_transaction, limit_copy);
 
-        count = get_message_idents(db, criteria, (int) local_limit, (int) offset + cur_count, 0, result);
+        count = get_message_idents(db, criteria, (int) local_limit, (int) offset + ((no_increment) ? 0 : cur_count), 0, result);
         if ( count < 0 )
                 return db_error(db, count, "retrieving alert ident failed");
 
@@ -630,6 +634,8 @@ static int copy_iterate(preludedb_t *src, preludedb_t *dst,
                 flush_transaction_if_needed(dst, dst_event_no, 1);
         }
 
+        flush_transaction_if_needed(dst, dst_event_no, 0);
+
         if ( delete_index ) {
                 stat_compute(stat_delete, count = delete(src, delete_tbl, delete_index), count);
                 if ( count < 0 ) {
@@ -679,7 +685,7 @@ static int do_cmd_copy_move(int argc, char **argv, prelude_bool_t delete_copied)
         transaction_start(dst);
 
         do {
-                count = ret = fetch_message_idents_limited(src, &idents);
+                count = ret = fetch_message_idents_limited(src, &idents, (delete_copied) ? TRUE : FALSE);
                 if ( count > 0 ) {
                         ret = copy_iterate(src, dst, idents, &dst_event_no, get_message,
                                            (delete_copied) ? delete_message_from_list : NULL,
@@ -743,7 +749,7 @@ static int cmd_delete(int argc, char **argv)
         transaction_start(db);
 
         do {
-                count = ret = fetch_message_idents_limited(db, &idents);
+                count = ret = fetch_message_idents_limited(db, &idents, TRUE);
                 if ( count > 0 ) {
                         ret = do_delete(db, idents, delete_message_from_result_idents, stat_delete);
                         preludedb_result_idents_destroy(idents);
@@ -855,7 +861,7 @@ static int cmd_save(int argc, char **argv)
         prelude_msgbuf_set_callback(msgbuf, save_msg);
 
         do {
-                count = ret = fetch_message_idents_limited(db, &idents);
+                count = ret = fetch_message_idents_limited(db, &idents, FALSE);
                 if ( count > 0 ) {
                         ret = save_iterate_message(db, idents, msgbuf, get_message, stat_fetch, stat_save);
                         preludedb_result_idents_destroy(idents);
@@ -886,6 +892,8 @@ static int do_read_message(prelude_io_t *io, prelude_msg_t **msg, idmef_message_
         if ( ret < 0 ) {
                 if ( prelude_error_get_code(ret) == PRELUDE_ERROR_EOF )
                         return 0;
+
+                return ret;
         }
 
         if ( offset_copy > 0 ) {
@@ -894,7 +902,7 @@ static int do_read_message(prelude_io_t *io, prelude_msg_t **msg, idmef_message_
                 return 1;
         }
 
-        if ( limit != -1 && cur_count >= limit ) {
+        if ( limit != -1 && cur_count >= (uint64_t) limit ) {
                 prelude_msg_destroy(*msg);
                 return 0;
         }
@@ -921,7 +929,10 @@ static int load_from_file(preludedb_t *db, prelude_io_t *io, stat_item_t *stat_f
         idmef_message_t *idmef;
 
         while ( ! stop_processing ) {
-                stat_compute(stat_fetch, ret = do_read_message(io, &msg, &idmef), 1);
+                stat_start(stat_fetch);
+                ret = do_read_message(io, &msg, &idmef);
+                stat_end(stat_fetch, (ret >= 0) ? ret : 0);
+
                 if ( ret < 0 ) {
                         fprintf(stderr, "error decoding IDMEF message: %s.\n", prelude_strerror(ret));
                         break;
@@ -1083,7 +1094,7 @@ static int cmd_print(int argc, char **argv)
         prelude_io_set_file_io(io, fd);
 
         do {
-                count = ret = fetch_message_idents_limited(db, &idents);
+                count = ret = fetch_message_idents_limited(db, &idents, FALSE);
                 if ( count > 0 ) {
                         ret = print_iterate_message(db, idents, io, get_message, stat_fetch, stat_print);
                         preludedb_result_idents_destroy(idents);
